import React from "react";
import ReactDOM from "react-dom/client";
import Init from "./index.tsx";
import "./index.css";
import { chatApiRequest } from "./lib/api.ts";
import { BotType } from "./types/bot.ts";

async function main() {
  try {
    const getScript = document.getElementById("devi-chat");
    if (!getScript) throw new Error(`No script tag found with id "devi-chat"`);

    const botId = getScript.dataset.botid;
    if (!botId) throw new Error(`No bot id found in script tag`);

    const apiUrl = getScript.dataset.apiurl || "https://website.ddevi.com";
    window.DEVI_BOT_API_URL = apiUrl;

    const noToggleButton = getScript.dataset.notogglebutton === "true";
    const defaultOpen = getScript.dataset.defaultopen === "true";
    const targetedDiv = getScript.dataset.targeteddiv;

    let usingTargetedDiv = false;

    let root = document.getElementById(targetedDiv || "devi-chat-root");
    if (!root) {
      root = document.createElement("div");
      root.id = "devi-chat-root";
      document.body.appendChild(root);
    } else {
      if (targetedDiv) {
        usingTargetedDiv = true;
      }
    }

    if (!import.meta.env.DEV) {
      const constructedSrc = (getScript.getAttribute("src") ?? "").replace(
        "index.js",
        "index.css"
      );
      const link = document.createElement("link");
      link.rel = "stylesheet";
      link.href = constructedSrc;
      document.head.appendChild(link);
      root.classList.add("dc");
      console.log(`Devi Chat: CSS loaded: ${constructedSrc}`);
    }

    const botInfo = await chatApiRequest(`/${botId}/public-info`).then(
      (d) => d.bot as BotType
    );
    console.log(`Devi Chat: Starting chat for bot ${botInfo._id}`);
    document.body.style.setProperty(
      "--dc-primary",
      botInfo.cssColor || "#000000"
    );

    ReactDOM.createRoot(root).render(
      <React.StrictMode>
        <Init
          botId={botId}
          noToggleButton={noToggleButton}
          defaultOpen={defaultOpen}
          usingTargetedDiv={usingTargetedDiv}
          chatOpenText={botInfo.chatOpenText}
        />
      </React.StrictMode>
    );
  } catch (error) {
    console.error(`Devi Chat Error: ${(error as Error).message}`);
  }
}

window.addEventListener("load", main);
