import { useChat } from "@/context";
import {
  CheckCircleIcon,
  ExclamationCircleIcon,
  XMarkIcon,
} from "@heroicons/react/24/solid";
import classNames from "classnames";
import { useEffect } from "react";

export default function Alert() {
  const { alert, setalert } = useChat();

  const dismissAlert = () => {
    setalert(null);
  };

  useEffect(() => {
    let timeout: any;
    if (alert) {
      timeout = setTimeout(() => {
        dismissAlert();
      }, 5000);
    }

    return () => {
      clearTimeout(timeout);
    };
  }, [alert]);

  return !alert ? null : (
    <div
      className={classNames(
        "absolute top-16 left-0 w-full text-left text-sm flex justify-between px-4 py-3 items-center font-medium gap-2",
        {
          "bg-red-100 text-red-500": alert.type === "ERROR",
          "bg-green-100 text-green-500": alert.type === "SUCCESS",
          "bg-yellow-100 text-yellow-500": alert.type === "WARNING",
        }
      )}
    >
      <div className="flex-1 flex items-center gap-2">
        {["ERROR", "WARNING"].includes(alert.type) ? (
          <ExclamationCircleIcon className="h-4 w-4" />
        ) : alert.type === "SUCCESS" ? (
          <CheckCircleIcon className="h-4 w-4" />
        ) : null}

        <p>{alert.message}</p>
      </div>

      <button onClick={dismissAlert} title="Dismiss alert">
        <XMarkIcon className="w-4 h-4" />
      </button>
    </div>
  );
}
