import { ExclamationTriangleIcon } from "@heroicons/react/24/solid";

export default function ChatUi({
  children,
  fullWidthHeight = false,
}: {
  children: React.ReactNode;
  fullWidthHeight?: boolean;
}) {
  return (
    <div
      className={
        fullWidthHeight
          ? `w-full h-full flex flex-col bg-white`
          : "w-full xs:max-w-lg fixed right-0 xs:right-5 h-full xs:h-[83vh] bottom-0 z-10 xs:bottom-[86px] shadow-md rounded-none xs:rounded-xl overflow-hidden flex flex-col bg-white"
      }
    >
      {children}
    </div>
  );
}

export function Skeleton() {
  return (
    <>
      <div className="flex-1 flex flex-col justify-center items-center">
        <div className="w-24 h-24 rounded-full bg-gray-200 animate-pulse mb-4"></div>
        <div className="w-3/4 h-4 rounded-full bg-gray-200 animate-pulse mb-2"></div>
        <div className="w-1/2 h-4 rounded-full bg-gray-200 animate-pulse mb-2"></div>
        <div className="w-1/3 h-4 rounded-full bg-gray-200 animate-pulse mb-2"></div>
      </div>
      <div className="h-16 flex items-center justify-center">
        <div className="w-1/2 h-4 rounded-full bg-gray-200 animate-pulse mb-2"></div>
      </div>
    </>
  );
}

export function ShowError({
  error,
  setopened,
}: {
  error: string;
  setopened: (opened: boolean) => void;
}) {
  return (
    <div className="px-5 w-full h-full flex justify-center items-center flex-col">
      <ExclamationTriangleIcon className="w-16 h-16 text-gray-400" />

      <div className="text-2xl font-bold text-gray-900 text-center mt-4">
        Snap!
      </div>

      <div className="text-gray-500 text-center mt-2 max-w-md w-full mb-4">
        {error}
      </div>

      <button
        onClick={() => setopened(false)}
        className="bg-[var(--dc-primary)] text-white px-4 py-1 rounded-md"
      >
        Close
      </button>
    </div>
  );
}
