import {
  ArrowDownTrayIcon,
  ArrowPathIcon,
  Bars2Icon,
  ClockIcon,
  XMarkIcon,
} from "@heroicons/react/24/solid";
import BotDP from "./dp";
import { useChat } from "@/context";
import { useState } from "react";
import { chatApiRequest } from "@/lib/api";

export default function BotHeader() {
  const { bot, toggleChat, chats, init, jwt, usingTargetedDiv } = useChat();

  const [menuOpen, setmenuOpen] = useState(false);

  return (
    <div className="py-3 pr-3 pl-4 bg-[var(--dc-primary)] flex items-center justify-between text-white relative">
      <div className="flex items-center gap-3">
        <BotDP />

        <div>
          <h1 className="text-sm font-medium">{bot.name}</h1>
          <p className="text-[10px] mt-0.5">
            <ClockIcon className="h-3 w-3 inline-block mr-1" />
            Replies instantly
          </p>
        </div>
      </div>

      <div className="flex gap-3 items-center">
        <button
          className="bg-white bg-opacity-20 p-1.5 rounded-md shadow-xl hover:bg-opacity-20"
          onClick={() => setmenuOpen(!menuOpen)}
        >
          {menuOpen ? (
            <XMarkIcon className="h-4 w-4" />
          ) : (
            <Bars2Icon className="h-4 w-4" />
          )}
        </button>

        <button
          className={`bg-white bg-opacity-20 p-1.5 rounded-md shadow-xl hover:bg-opacity-20 ${
            usingTargetedDiv ? "hidden" : "xs:hidden"
          }`}
          onClick={() => toggleChat()}
        >
          <XMarkIcon className="h-4 w-4" />
        </button>
      </div>

      <div
        className={`absolute top-14 right-2.5 bg-white text-black p-1.5 rounded-md shadow-xl ${
          menuOpen ? "block" : "hidden"
        }`}
      >
        <SettingsItem
          title="Restart"
          Icon={ArrowPathIcon}
          onClick={async () => {
            try {
              const deleteThread = await chatApiRequest(
                `/${bot._id}/thread/delete-thread`,
                {
                  reason: "BUTTON_RESTART",
                  jwt: jwt,
                }
              );
              console.log(`Thread deleted:`, deleteThread);
            } catch (error) {
              console.log(`Failed to delete thread:`, error);
            }

            init();
          }}
        />
        <SettingsItem
          title="Download transcript"
          Icon={ArrowDownTrayIcon}
          onClick={() => {
            const data = chats.map((chat) => {
              return `${chat.role.toUpperCase()}: ${chat.message.replace(
                /\n/g,
                " "
              )}`;
            });
            const blob = new Blob(
              [
                `Transcript of ${
                  bot.name
                } at ${new Date().toLocaleString()}\n\n` + data.join("\n\n"),
              ],
              { type: "text/plain" }
            );
            const url = window.URL.createObjectURL(blob);
            const a = document.createElement("a");
            a.href = url;
            a.download = `transcript-${Date.now()}.txt`;
            a.click();
          }}
        />
      </div>
    </div>
  );
}

function SettingsItem({
  title,
  onClick,
  Icon,
}: {
  title: string;
  onClick: () => void;
  Icon: any;
}) {
  return (
    <button
      className="flex items-center gap-2.5 text-sm text-left w-full py-1 px-3 rounded-md hover:bg-gray-100"
      onClick={onClick}
    >
      <Icon className="h-4 w-4" />
      <span>{title}</span>
    </button>
  );
}
