import { BotType } from "@/types/bot";
import { useMemo, useState } from "react";
import { AlertType, ChatContext, defaultChatState } from "@/context";
import BotHeader from "@/components/header";
import BotSendMessage from "@/components/send-message";
import BotMessageList from "@/components/message-list";
import { ChatType } from "@/types/chat";
import Alert from "./alert";

declare global {
  interface Window {
    chatSetState: typeof defaultChatState.setstate;
  }
}

export default function BotChatUi({
  bot,
  chats,
  toggle = () => {},
  jwt,
  init,
  usingTargetedDiv,
}: {
  bot: BotType;
  chats: ChatType[];
  jwt: string;
  toggle: () => void;
  init: () => void;
  usingTargetedDiv: boolean;
}) {
  const [state, setstate] = useState({
    ...defaultChatState,
    bot: bot as any,
    chats: chats,
    isBotReplying: false,
    alert: null,
  });

  const memod = useMemo(() => {
    const md = {
      ...state,
      toggleChat: toggle,
      jwt,
      init,
      usingTargetedDiv,
      setstate: (key: string, value: string) =>
        setstate((prev) => ({ ...prev, [key]: value })),
      setalert: (alert: AlertType) =>
        setstate((prev) => ({ ...prev, alert: alert as any })),
    };

    if (typeof window !== "undefined") {
      window["chatSetState"] = md.setstate;
    }

    return md;

    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [state, jwt]);

  return (
    <ChatContext.Provider value={memod}>
      <Alert />
      <BotHeader />
      <BotMessageList />
      <BotSendMessage />
    </ChatContext.Provider>
  );
}
