import { createContext, useContext } from "react";
import { BotType } from "@/types/bot";
import { ChatType } from "@/types/chat";

type ChatContextState = {
  bot: Omit<BotType, "files">;
  setstate: (key: string, value: any) => void;
  chats: ChatType[];
  isBotReplying: boolean;
  jwt: string;
  toggleChat: () => void;
  init: () => void;
  usingTargetedDiv: boolean;
  alert: null | { type: "SUCCESS" | "ERROR" | "WARNING"; message: string };
  setalert: (alert: AlertType) => void;
};

export type AlertType = ChatContextState["alert"];

export const defaultChatState: Partial<ChatContextState> = {
  setstate: () => {},
  chats: [],
  isBotReplying: false,
  jwt: "",
  toggleChat: () => {},
  init: () => {},
  alert: null,
  setalert: () => {},
};

export const ChatContext = createContext<ChatContextState>({
  ...(defaultChatState as ChatContextState),
});

export const useChat = () => {
  return useContext(ChatContext);
};
