import axios from "axios";
import {
  BadRequestError,
  ErrorType,
  UnauthorizedError,
  NotFoundError,
  InternalServerError,
} from "@/lib/errors";

declare global {
  interface Window {
    DEVI_BOT_API_URL: string;
  }
}

export const chatApiRequest = async (url: string, data?: any) => {
  try {
    const response = await axios[data ? "post" : "get"](
      `${window.DEVI_BOT_API_URL}/api/bot${url}`,
      data || undefined
    );
    return response.data;
  } catch (error) {
    const errorType =
      (error as any).response?.data?.type || "InternalServerError";

    switch (errorType) {
      case ErrorType.BadRequestError:
        throw new BadRequestError(
          (error as any).response?.data?.message || "Bad Request"
        );
      case ErrorType.UnauthorizedError:
        throw new UnauthorizedError(
          (error as any).response?.data?.message || "Unauthorized"
        );
      case ErrorType.NotFoundError:
        throw new NotFoundError(
          (error as any).response?.data?.message || "Not Found"
        );

      default:
        throw new InternalServerError(
          (error as any).response?.data?.message || "Something went wrong"
        );
    }
  }
};
